..
   Copyright 2011 Josh Kearney

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

.. pyhole documentation master file, created by
   sphinx-quickstart on Mon Jun 13 10:43:49 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Pyhole Documentation
====================

A modular IRC bot for Python developers.

Install Pyhole
--------------

.. toctree::
   :maxdepth: 2

   installation

Getting Involved
----------------

.. toctree::
   :maxdepth: 2

   guidelines
   writing
   github

The Code
--------

.. toctree::
   :maxdepth: 2

   pyhole
   plugins
   tests

Other
-----

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

